- Fix calculation of node impurity in :class:`tree.DecisionTreeRegressor`,
  :class:`ensemble.RandomForestRegressor`,  :class:`ensemble.ExtraTreeRegressor` and
  :class:`ensemble.ExtraTreesRegressor` when missing values are present for the Poisson
  criterion. The Poisson criterion was returning invalid impurities (including
  negative values) when missing values were present.
  By :user:`Arthur Lacote <cakedev0>`.
